"""geographiclib: geodesic routines from GeographicLib"""

__version_info__ = (2,
                    0,
                    0)
"""GeographicLib version as a tuple"""

__version__ = "2.0"
"""GeographicLib version as a string"""

__release_date__ = "2022-04-23"
"""GeographicLib release date"""



"""

test_geodesic: test the geodesic routines from GeographicLib

Run these tests with one of

    python2 -m unittest -v geographiclib.test.test_geodesic
    python3 -m unittest -v geographiclib.test.test_geodesic

executed in this directory's parent directory.

"""
